import { revalidatePath } from "next/cache";
import JobCard from "./_jobcard/JobCard";

interface JobPosting {
  title: string;
  logo: string;
  company: string;
  location: string;
  type: string;
  description: string;
  link: string;
  skills: {
    react: boolean;
    python: boolean;
    golang: boolean;
    svelte: boolean;
    nextjs: boolean;
    typescript: boolean;
    tailwind: boolean;
  };
}

async function fetchJobs(): Promise<JobPosting[]> {
  const response = await fetch("http://51.20.250.24/jobs", {
    cache: "no-cache",
  });
  if (!response.ok) {
    throw new Error("Failed to fetch jobs");
  }

  revalidatePath("/");
  return response.json();
}

export default async function Home() {
  const jobs = await fetchJobs();
  return (
    <main>
      {jobs.map((job, i) => (
        <JobCard key={i} job={job} />
      ))}
    </main>
  );
}
